@@ -207,7 +207,7 @@ class Xlsx2csv:
     def getSheetIdByName(self, name):
         for s in self.workbook.sheets:
             if s['name'] == name:
-                return s['id']
+                return s['index']
         return None
 
     def convert(self, outfile, sheetid=1):
@@ -254,8 +254,7 @@ class Xlsx2csv:
                 if isinstance(outfile, str):
                     of = os.path.join(outfile, sheetname + '.csv')
                 elif self.options['sheetdelimiter'] and len(self.options['sheetdelimiter']):
-                    of.write(self.options['sheetdelimiter'] + " " + str(s['index']) + " - " + sheetname + self.options[
-                        'lineterminator'])
+                    of.write(self.options['sheetdelimiter'] + " " + str(s['index']) + " - " + sheetname + self.options['lineterminator'])
                 self._convert(s['index'], of)
 
     def _convert(self, sheet_index, outfile):
@@ -394,7 +393,7 @@ class Workbook:
             relation_id = None
             if 'r:id' in attrs:
                 relation_id = attrs['r:id'].value
-            self.sheets.append({'name': name, 'relation_id': relation_id, 'index': i + 1})
+            self.sheets.append({'name': name, 'relation_id': relation_id, 'index': i + 1, 'id': i + 1}) # remove id starting 0.8.0 version
 
 
 class ContentTypes:
